﻿using Hotline.Share.Enums.Snapshot;
using Hotline.Share.Requests;
using Hotline.Share.Tools;
using System.ComponentModel.DataAnnotations;

namespace Hotline.Share.Dtos.Snapshot;
public class RedPackOutDto 
{ 
    public string Title { get; set; }    
    public DateTime CreationTime { get; set; }
    public string CreationTimeText => CreationTime.ToString("yyyy-MM-dd HH:mm:ss");

    /// <summary>
    /// 金额(单位:元)
    /// </summary>
    public string AmountTxt => Amount.ToYuanFinance();

    /// <summary>
    /// 金额(单位:元)
    /// </summary>
    public double Amount { get; set; }
}

public class RedPacksInDto : QueryFixedDto
{ 
    /// <summary>
    /// 时间; 格式:yyyy-MM
    /// </summary>
    [Required]
    public string Time { get; set; } = DateTime.Now.ToString("yyyy-MM");

    /// <summary>
    /// 红包状态
    /// </summary>
    public ERedPackPickupStatus Status { get; set; }
}

public class RedPackDateInDto : QueryFixedDto
{
    /// <summary>
    /// 红包状态
    /// </summary>
    public ERedPackPickupStatus Status { get; set; }
}

public class RedPackDateOutDto
{ 
    /// <summary>
    /// 时间
    /// </summary>
    public DateTime CreationTime { get; set; }

    public string CreationTimeText => CreationTime.ToString("yyyy-MM");

    /// <summary>
    /// 金额(单位:元)
    /// </summary>
    public double Amount { get; set; }

    /// <summary>
    /// 金额(单位:元)
    /// </summary>
    public string AmountTxt => Amount.ToYuanFinance();
}

public class UpdateRedPackAuditRemarkInDto
{
    /// <summary>
    /// Id
    /// </summary>
    public string RedPackAuditId { get; set; }

    /// <summary>
    /// 实发金额
    /// </summary>
    public double AcutalAmount { get; set; }

    /// <summary>
    /// 市民奖励发放备注
    /// </summary>
    public string SendRemarks { get; set; }

    /// <summary>
    /// 市民奖励发放结果
    /// </summary>
    public bool IsSend { get; set; }

    /// <summary>
    /// 红包发放失败原因;
    /// 0: 无法联系;
    /// 1: 婉拒红包;
    /// </summary>
    public ERedPackPickupFailCase FailCase { get; set; }
}

